@@ -10,3 +10,7 @@ class DbtCloudAccount(DbtCloudAPI):
 
     def get_api_url(self, api_version: str = "v2") -> str:
         return f"https://cloud.getdbt.com/api/{api_version}/accounts/{self.account_id}"
+
+    @property
+    def authorization_headers(self):
+        return {"Authorization": f"Token {self.api_token}"}
