@@ -3,7 +3,7 @@ import os
 from enum import Enum
 from typing import Optional, List, Tuple
 from pathlib import Path
-from pydantic import Field
+from pydantic import Field, validator
 from dbt_cloud.account import DbtCloudAccount
 from dbt_cloud.args import ArgsBaseModel, DbtCloudArgsBaseModel
 from dbt_cloud.run import DbtCloudRun
@@ -64,6 +64,10 @@ class DbtCloudJobRunArgs(DbtCloudJobArgs):
         description="Override the list of steps for this job"
     )
 
+    @validator("steps_override")
+    def check_steps_override_is_none_if_empty(cls, value):
+        return value or None
+
 
 class DbtCloudJobGetArgs(DbtCloudJobArgs):
     order_by: Optional[str] = Field(
@@ -141,7 +145,7 @@ class DbtCloudJob(DbtCloudAccount):
     def get(self, order_by: str = None) -> requests.Response:
         response = requests.get(
             url=f"{self.get_api_url()}/",
-            headers={"Authorization": f"Token {self.api_token}"},
+            headers=self.authorization_headers,
             params={"order_by": order_by},
         )
         return response
@@ -149,7 +153,7 @@ class DbtCloudJob(DbtCloudAccount):
     def create(self, args: DbtCloudJobCreateArgs) -> requests.Response:
         response = requests.post(
             url=f"{self.get_api_url()}/",
-            headers={"Authorization": f"Token {self.api_token}"},
+            headers=self.authorization_headers,
             json=args.get_payload(),
         )
         return response
@@ -157,7 +161,7 @@ class DbtCloudJob(DbtCloudAccount):
     def delete(self):
         response = requests.delete(
             url=f"{self.get_api_url()}/",
-            headers={"Authorization": f"Token {self.api_token}"},
+            headers=self.authorization_headers,
             json={},
         )
         return response
@@ -166,7 +170,7 @@ class DbtCloudJob(DbtCloudAccount):
         assert str(args.job_id) == str(self.job_id), f"{args.job_id} != {self.job_id}"
         response = requests.post(
             url=f"{self.get_api_url()}/run/",
-            headers={"Authorization": f"Token {self.api_token}"},
+            headers=self.authorization_headers,
             json=args.get_payload(),
         )
         run_id = response.json()["data"]["id"]
